@@ -28,7 +28,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-lib-self-check-functions.h"
 #include "nautilus-metadata.h"
-#include "nautilus-metafile.h"
 #include "nautilus-file.h"
 #include "nautilus-search-directory.h"
 #include "nautilus-signaller.h"
@@ -276,8 +275,11 @@ xdg_dir_changed (NautilusFile *file,
 				      G_SPAWN_STDERR_TO_DEV_NULL,
 				      NULL, NULL,
 				      NULL, NULL, NULL, NULL);
+			g_reload_user_special_dirs_cache ();
 			schedule_user_dirs_changed ();
 			desktop_dir_changed ();
+			/* Icon might have changed */
+			nautilus_file_invalidate_attributes (file, NAUTILUS_FILE_ATTRIBUTE_INFO);
 		}
 	}
 	g_object_unref (location);
@@ -367,6 +369,7 @@ update_xdg_dir_cache (void)
 	int i;
 
 	free_xdg_dir_cache ();
+	g_reload_user_special_dirs_cache ();
 	schedule_user_dirs_changed ();
 	desktop_dir_changed ();
 
