@@ -66,7 +66,7 @@ fm_empty_view_add_file (FMDirectoryView *view, NautilusFile *file, NautilusDirec
 	elaps = g_timer_elapsed (timer, NULL);
 	g_timer_stop (timer);
 
-	gdk_pixbuf_unref (icon);
+	g_object_unref (icon);
 	
 	cumu += elaps;
 	g_message ("entire loading: %.3f, cumulative %.3f", elaps, cumu);
@@ -356,7 +356,7 @@ fm_empty_view_create (NautilusWindowSlotInfo *slot)
 			     "window-slot", slot,
 			     NULL);
 	g_object_ref (view);
-	gtk_object_sink (GTK_OBJECT (view));
+
 	return NAUTILUS_VIEW (view);
 }
 
