@@ -1991,7 +1991,7 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 			
 	if (start_flag) {
 		icon_view->details->audio_preview_file = file;
-		icon_view->details->audio_preview_timeout = g_timeout_add (1000, play_file, icon_view);
+		icon_view->details->audio_preview_timeout = g_timeout_add_seconds (1, play_file, icon_view);
 	}
 }
 
@@ -2993,7 +2993,6 @@ fm_icon_view_create (NautilusWindowSlotInfo *slot)
 			     "compact", FALSE,
 			     NULL);
 	g_object_ref (view);
-	gtk_object_sink (GTK_OBJECT (view));
 	return NAUTILUS_VIEW (view);
 }
 
@@ -3007,7 +3006,6 @@ fm_compact_view_create (NautilusWindowSlotInfo *slot)
 			     "compact", TRUE,
 			     NULL);
 	g_object_ref (view);
-	gtk_object_sink (GTK_OBJECT (view));
 	return NAUTILUS_VIEW (view);
 }
 
