@@ -120,7 +120,7 @@ struct SelectionForeachData {
 #define LIST_VIEW_MINIMUM_ROW_HEIGHT	28
 
 /* We wait two seconds after row is collapsed to unload the subdirectory */
-#define COLLAPSE_TO_UNLOAD_DELAY 2000 
+#define COLLAPSE_TO_UNLOAD_DELAY 2 
 
 /* Wait for the rename to end when activating a file being renamed */
 #define WAIT_FOR_RENAME_ON_ACTIVATE 200
@@ -890,7 +890,7 @@ row_collapsed_callback (GtkTreeView *treeview, GtkTreeIter *iter, GtkTreePath *p
 
 	eel_add_weak_pointer (&unload_data->view);
 	
-	g_timeout_add (COLLAPSE_TO_UNLOAD_DELAY,
+	g_timeout_add_seconds (COLLAPSE_TO_UNLOAD_DELAY,
 		       unload_file_timeout,
 		       unload_data);
 }
@@ -1007,19 +1007,24 @@ sort_criterion_changes_due_to_user (GtkTreeView *tree_view)
 	GtkTreeViewColumn *column;
 	GSignalInvocationHint *ihint;
 	unsigned int sort_signal_id;
+	gboolean ret;
 
 	sort_signal_id = g_signal_lookup ("clicked", gtk_tree_view_column_get_type ());
 
+	ret = FALSE;
+
 	columns = gtk_tree_view_get_columns (tree_view);
 	for (p = columns; p != NULL; p = p->next) {
 		column = p->data;
 		ihint = g_signal_get_invocation_hint (column);
 		if (ihint != NULL) {
-			return TRUE;
+			ret = TRUE;
+			break;
 		}
 	}
+	g_list_free (columns);
 
-	return FALSE;
+	return ret;
 }
 
 static void
@@ -1344,7 +1349,7 @@ create_and_set_up_tree_view (FMListView *view)
 
 	/* Don't handle backspace key. It's used to open the parent folder. */
 	binding_set = gtk_binding_set_by_class (GTK_WIDGET_GET_CLASS (view->details->tree_view));
-	gtk_binding_entry_clear (binding_set, GDK_BackSpace, 0);
+	gtk_binding_entry_remove (binding_set, GDK_BackSpace, 0);
 
 	view->details->drag_dest = 
 		nautilus_tree_view_drag_dest_new (view->details->tree_view);
@@ -1440,7 +1445,6 @@ create_and_set_up_tree_view (FMListView *view)
 			
 			view->details->file_name_column = gtk_tree_view_column_new ();
 			g_object_ref (view->details->file_name_column);
-			gtk_object_sink (GTK_OBJECT (view->details->file_name_column));
 			view->details->file_name_column_num = column_num;
 			
 			g_hash_table_insert (view->details->columns,
@@ -1479,7 +1483,6 @@ create_and_set_up_tree_view (FMListView *view)
 									   "text", column_num,
 									   NULL);
 			g_object_ref (column);
-			gtk_object_sink (GTK_OBJECT (column));
 			gtk_tree_view_column_set_sort_column_id (column, column_num);
 			g_hash_table_insert (view->details->columns, 
 					     g_strdup (name), 
@@ -1530,8 +1533,7 @@ get_visible_columns (FMListView *list_view)
 
 	visible_columns = nautilus_file_get_metadata_list 
 		(file,
-		 NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS,
-		 NAUTILUS_METADATA_SUBKEY_COLUMNS);
+		 NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS);
 
 	if (visible_columns) {
 		GPtrArray *res;
@@ -1562,8 +1564,7 @@ get_column_order (FMListView *list_view)
 
 	column_order = nautilus_file_get_metadata_list 
 		(file,
-		 NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER,
-		 NAUTILUS_METADATA_SUBKEY_COLUMNS);
+		 NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER);
 
 	if (column_order) {
 		GPtrArray *res;
@@ -2048,7 +2049,6 @@ column_chooser_changed_callback (NautilusColumnChooser *chooser,
 	list = g_list_reverse (list);
 	nautilus_file_set_metadata_list (file,
 					 NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS,
-					 NAUTILUS_METADATA_SUBKEY_COLUMNS,
 					 list);
 	g_list_free (list);
 
@@ -2059,7 +2059,6 @@ column_chooser_changed_callback (NautilusColumnChooser *chooser,
 	list = g_list_reverse (list);
 	nautilus_file_set_metadata_list (file,
 					 NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER,
-					 NAUTILUS_METADATA_SUBKEY_COLUMNS,
 					 list);
 	g_list_free (list);
 
@@ -2102,8 +2101,8 @@ column_chooser_use_default_callback (NautilusColumnChooser *chooser,
 	file = fm_directory_view_get_directory_as_file 
 		(FM_DIRECTORY_VIEW (view));
 
-	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER, NAUTILUS_METADATA_SUBKEY_COLUMNS, NULL);
-	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS, NAUTILUS_METADATA_SUBKEY_COLUMNS, NULL);
+	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER, NULL);
+	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS, NULL);
 
 	set_columns_settings_from_metadata_and_preferences (FM_LIST_VIEW (view));
 	column_chooser_set_from_settings (chooser, view);
@@ -2276,8 +2275,8 @@ fm_list_view_reset_to_defaults (FMDirectoryView *view)
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_COLUMN, NULL, NULL);
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED, NULL, NULL);
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_ZOOM_LEVEL, NULL, NULL);
-	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER, NAUTILUS_METADATA_SUBKEY_COLUMNS, NULL);
-	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS, NAUTILUS_METADATA_SUBKEY_COLUMNS, NULL);
+	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_COLUMN_ORDER, NULL);
+	nautilus_file_set_metadata_list (file, NAUTILUS_METADATA_KEY_LIST_VIEW_VISIBLE_COLUMNS, NULL);
 
 	gtk_tree_sortable_set_sort_column_id
 		(GTK_TREE_SORTABLE (FM_LIST_VIEW (view)->details->model),
@@ -2892,7 +2891,6 @@ fm_list_view_create (NautilusWindowSlotInfo *slot)
 			     "window-slot", slot,
 			     NULL);
 	g_object_ref (view);
-	gtk_object_sink (GTK_OBJECT (view));
 	return NAUTILUS_VIEW (view);
 }
 
